# Brave Search Goggles

Goggles enable anyone, be it individuals or a community, to alter the ranking
of Brave search by using a set of instructions (rules and filters). Anyone can
create, apply, or extend a Goggle. Essentially Goggles act as a custom
re-ranking on top of Brave’s search index.

This means that, instead of a single ranking, Brave Search can offer an almost
limitless number of ranking options. While Brave Search doesn't have editorial
biases, all search engines have some level of intrinsic bias due to underlying
data (the Web) and some algorithmic choices of features to select. Goggles
allows for users to counter such intrinsic biases in the ranking, and also to
create custom search experiences that couldn’t be covered by an all-purpose
search engine such as Brave Search.

Goggles are owned solely by their creators and, if public, can be used by
anyone on top of Brave Search index.

Check out the [official github repository](https://github.com/brave/goggles-quickstart/tree/main) for more information on how to create and use Goggles.

Want to learn more about the motivation for Goggles? Check out the [Goggles whitepaper](https://brave.com/goggles).

# This repo will host public goggles contributed by the community and be accessible as part of the package.

- Thought Leadership
- Academic Research
